@@ -1,4 +1,5 @@
 from multiprocessing import Pool, cpu_count
+import warnings
 
 import numpy as np
 from scipy.ndimage import affine_transform
@@ -55,8 +56,8 @@ def reslice(data, affine, zooms, new_zooms, order=1, mode='constant', cval=0,
     >>> data = img.get_data()
     >>> data.shape == (58, 58, 24)
     True
-    >>> affine = img.get_affine()
-    >>> zooms = img.get_header().get_zooms()[:3]
+    >>> affine = img.affine
+    >>> zooms = img.header.get_zooms()[:3]
     >>> zooms
     (4.0, 4.0, 5.0)
     >>> new_zooms = (3.,3.,3.)
@@ -66,6 +67,11 @@ def reslice(data, affine, zooms, new_zooms, order=1, mode='constant', cval=0,
     >>> data2.shape == (77, 77, 40)
     True
     """
+    # We are suppressing warnings emitted by scipy >= 0.18,
+    # described in https://github.com/nipy/dipy/issues/1107.
+    # These warnings are not relevant to us, as long as our offset
+    # input to scipy's affine_transform is [0, 0, 0]
+    warnings.simplefilter("ignore")
     new_zooms = np.array(new_zooms, dtype='f8')
     zooms = np.array(zooms, dtype='f8')
     R = new_zooms / zooms
@@ -97,4 +103,6 @@ def reslice(data, affine, zooms, new_zooms, order=1, mode='constant', cval=0,
     Rx = np.eye(4)
     Rx[:3, :3] = np.diag(R)
     affine2 = np.dot(affine, Rx)
+    # Turn warnings back on:
+    warnings.filterwarnings('always')
     return data2, affine2
