@@ -4,6 +4,7 @@ from __future__ import division, print_function, absolute_import
 import math
 import numpy as np
 import numpy.linalg as npl
+from dipy.testing import setup_test
 
 # epsilon for testing whether a number is close to zero
 _EPS = np.finfo(float).eps * 4.0
@@ -166,10 +167,10 @@ def normalized_vector(vec, axis=-1):
     >>> np.allclose(np.array(vec) / l2n, nvec)
     True
     >>> vec = np.array([[1, 2, 3]])
-    >>> vec.shape
-    (1, 3)
-    >>> normalized_vector(vec).shape
-    (1, 3)
+    >>> vec.shape == (1, 3)
+    True
+    >>> normalized_vector(vec).shape == (1, 3)
+    True
     '''
     return vec / vector_norm(vec, axis, keepdims=True)
 
