@@ -4,19 +4,20 @@
 import os
 import subprocess
 
-from ..utils.optpkg import optional_package
+from dipy.utils.optpkg import optional_package
 
 cProfile, _, _ = optional_package('cProfile')
 pstats, _, _ = optional_package('pstats',
                                 'pstats is not installed.  It is part of the'
                                 'python-profiler package in Debian/Ubuntu')
 
+
 class Profiler():
     ''' Profile python/cython files or functions
-    
-    If you are profiling cython code you need to add    
+
+    If you are profiling cython code you need to add
     # cython: profile=True on the top of your .pyx file
-    
+
     and for the functions that you do not want to profile you can use
     this decorator in your cython files
 
@@ -30,7 +31,7 @@ class Profiler():
     Attributes
     ------------
     stats : function, stats.print_stats(10) will prin the 10 slower functions
-    
+
     Examples
     -----------
     from dipy.core.profile import Profiler
@@ -46,44 +47,43 @@ class Profiler():
     http://docs.cython.org/src/tutorial/profiling_tutorial.html
     http://docs.python.org/library/profile.html
     http://packages.python.org/line_profiler/
-    
+
     '''
 
-    def __init__(self,call=None,*args):
+    def __init__(self, call=None, *args):
         # Delay import until use of class instance.  We were getting some very
         # odd build-as-we-go errors running tests and documentation otherwise
         import pyximport
         pyximport.install()
 
         try:
-            
-            ext=os.path.splitext(call)[1].lower()        
-            print('ext',ext)               
-            if ext == '.py' or ext == '.pyx': #python/cython file
+
+            ext = os.path.splitext(call)[1].lower()
+            print('ext', ext)
+            if ext == '.py' or ext == '.pyx':  # python/cython file
                 print('profiling python/cython file ...')
-                subprocess.call(['python','-m','cProfile', \
-                                 '-o','profile.prof',call])
-                s = pstats.Stats('profile.prof')            
-                stats=s.strip_dirs().sort_stats('time')
-                self.stats=stats
-            
+                subprocess.call(['python', '-m', 'cProfile',
+                                 '-o', 'profile.prof', call])
+                s = pstats.Stats('profile.prof')
+                stats = s.strip_dirs().sort_stats('time')
+                self.stats = stats
+
         except:
 
-            print('profiling function call ...')   
-            self.args=args
-            self.call=call
+            print('profiling function call ...')
+            self.args = args
+            self.call = call
 
-            cProfile.runctx('self._profile_function()',globals(),locals(),\
-                                'profile.prof')
+            cProfile.runctx('self._profile_function()', globals(), locals(),
+                            'profile.prof')
             s = pstats.Stats('profile.prof')
-            stats=s.strip_dirs().sort_stats('time')
-            self.stats=stats
-
+            stats = s.strip_dirs().sort_stats('time')
+            self.stats = stats
 
     def _profile_function(self):
         self.call(*self.args)
 
-    def print_stats(self,N=10):
+    def print_stats(self, N=10):
         ''' Print stats for profiling
 
         You can use it in all different ways developed in pstats
@@ -92,7 +92,7 @@ class Profiler():
         or
         print_stats('function_name')
         will give you the stats for all the calls with name 'function_name'
-                
+
         Parameters
         ------------
         N : stats.print_stats argument
