@@ -1,9 +1,9 @@
 """ Load and save pickles """
 # Python 3 merged cPickle into pickle
-from ..utils.six.moves import cPickle
+from dipy.utils.six.moves import cPickle
 
 
-def save_pickle(fname,dix):
+def save_pickle(fname, dix):
     ''' Save `dix` to `fname` as pickle
 
     Parameters
@@ -32,8 +32,8 @@ def save_pickle(fname,dix):
     dipy.io.pickles.load_pickle
 
     '''
-    out=open(fname,'wb')
-    cPickle.dump(dix,out,protocol=cPickle.HIGHEST_PROTOCOL)
+    out = open(fname, 'wb')
+    cPickle.dump(dix, out, protocol=cPickle.HIGHEST_PROTOCOL)
     out.close()
 
 
@@ -54,7 +54,7 @@ def load_pickle(fname):
     ----------
     dipy.io.pickles.save_pickle
     '''
-    inp=open(fname,'rb')
+    inp = open(fname, 'rb')
     dix = cPickle.load(inp)
     inp.close()
     return dix
