@@ -5,12 +5,12 @@ import tempfile
 
 import numpy as np
 import numpy.testing as npt
-from nose.tools import assert_raises
 
 from dipy.data import get_data
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.core.gradients import gradient_table
 
+
 def test_read_bvals_bvecs():
     fimg, fbvals, fbvecs = get_data('small_101D')
     bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
@@ -31,7 +31,7 @@ def test_read_bvals_bvecs():
     # Test for error raising with incorrect file-contents:
 
     # These bvecs only have two rows/columns:
-    new_bvecs1 = bvecs[:,:2]
+    new_bvecs1 = bvecs[:, :2]
     # Make a temporary file
     bv_file1 = tempfile.NamedTemporaryFile(mode='wt')
     # And fill it with these 2-columned bvecs:
@@ -39,21 +39,24 @@ def test_read_bvals_bvecs():
         bv_file1.file.write('%s %s\n' %
                             (new_bvecs1[x][0], new_bvecs1[x][1]))
     bv_file1.close()
-    npt.assert_raises(IOError,read_bvals_bvecs, fbvals, bv_file1.name)
+    npt.assert_raises(IOError, read_bvals_bvecs, fbvals, bv_file1.name)
 
     # These bvecs are saved as one long array:
     new_bvecs2 = np.ravel(bvecs)
     bv_file2 = tempfile.NamedTemporaryFile()
     np.save(bv_file2, new_bvecs2)
     bv_file2.close()
-    npt.assert_raises(IOError,read_bvals_bvecs, fbvals, bv_file2.name)
+    npt.assert_raises(IOError, read_bvals_bvecs, fbvals, bv_file2.name)
 
-    # Theres less bvecs than bvals:
+    # There are less bvecs than bvals:
     new_bvecs3 = bvecs[:-1, :]
     bv_file3 = tempfile.NamedTemporaryFile()
     np.save(bv_file3, new_bvecs3)
     bv_file3.close()
-    npt.assert_raises(IOError,read_bvals_bvecs, fbvals, bv_file3.name)
+    npt.assert_raises(IOError, read_bvals_bvecs, fbvals, bv_file3.name)
+
+    # You entered the bvecs on both sides:
+    npt.assert_raises(IOError, read_bvals_bvecs, fbvecs, fbvecs)
 
 
 if __name__ == '__main__':
