@@ -320,6 +320,7 @@ class ConstrainedSDTModel(SphHarmModel):
         Z = np.linalg.norm(qball_odf)
         # normalize ODF
         odf_sh /= Z
+
         shm_coeff, num_it = odf_deconv(odf_sh, self.R, self.B_reg,
                                        self.lambda_, self.tau)
         # print 'SDT CSD converged after %d iterations' % num_it
@@ -759,8 +760,42 @@ def odf_sh_to_sharp(odfs_sh, sphere, basis=None, ratio=3 / 15., sh_order=8,
     return fodf_sh
 
 
+def fa_superior(FA, fa_thr):
+    """ Check that the FA is greater than the FA threshold
+
+        Parameters
+        ----------
+        FA : array
+            Fractional Anisotropy
+        fa_thr : int
+            FA threshold
+
+        Returns
+        -------
+        True when the FA value is greater than the FA threshold, otherwise False.
+    """
+    return FA > fa_thr
+
+
+def fa_inferior(FA, fa_thr):
+    """ Check that the FA is lower than the FA threshold
+
+        Parameters
+        ----------
+        FA : array
+            Fractional Anisotropy
+        fa_thr : int
+            FA threshold
+
+        Returns
+        -------
+        True when the FA value is lower than the FA threshold, otherwise False.
+    """
+    return FA < fa_thr
+
+
 def auto_response(gtab, data, roi_center=None, roi_radius=10, fa_thr=0.7,
-                  return_number_of_voxels=False):
+                  fa_callable=fa_superior, return_number_of_voxels=False):
     """ Automatic estimation of response function using FA.
 
     Parameters
@@ -775,6 +810,10 @@ def auto_response(gtab, data, roi_center=None, roi_radius=10, fa_thr=0.7,
         radius of cubic ROI
     fa_thr : float
         FA threshold
+    fa_callable : callable
+        A callable that defines an operation that compares FA with the fa_thr. The operator
+        should have two positional arguments (e.g., `fa_operator(FA, fa_thr)`) and it should
+        return a bool array.
     return_number_of_voxels : bool
         If True, returns the number of voxels used for estimating the response
         function.
@@ -831,7 +870,7 @@ def auto_response(gtab, data, roi_center=None, roi_radius=10, fa_thr=0.7,
     tenfit = ten.fit(roi)
     FA = fractional_anisotropy(tenfit.evals)
     FA[np.isnan(FA)] = 0
-    indices = np.where(FA > fa_thr)
+    indices = np.where(fa_callable(FA, fa_thr))
 
     if indices[0].size == 0:
         msg = "No voxel with a FA higher than " + str(fa_thr) + " were found."
