@@ -1,10 +1,10 @@
 """ Classes and functions for generalized q-sampling """
 import numpy as np
-from .odf import OdfModel, OdfFit, gfa
-from .cache import Cache
+from dipy.reconst.odf import OdfModel, OdfFit, gfa
+from dipy.reconst.cache import Cache
 import warnings
-from .multi_voxel import multi_voxel_fit
-from .recspeed import local_maxima, remove_similar_vertices
+from dipy.reconst.multi_voxel import multi_voxel_fit
+from dipy.reconst.recspeed import local_maxima, remove_similar_vertices
 
 
 class GeneralizedQSamplingModel(OdfModel, Cache):
@@ -37,13 +37,13 @@ class GeneralizedQSamplingModel(OdfModel, Cache):
 
         .. [2] Garyfallidis E, "Towards an accurate brain tractography", PhD
         thesis, University of Cambridge, 2012.
-        
+
         Notes
         -----
         As of version 0.9, range of the sampling length in GQI2 has changed
-	to match the same scale used in the 'standard' method [1]_. This 
-        means that the value of `sampling_length` should be approximately 
-        1 - 1.3 (see [1]_, pg. 1628). 
+        to match the same scale used in the 'standard' method [1]_. This
+        means that the value of `sampling_length` should be approximately
+        1 - 1.3 (see [1]_, pg. 1628).
 
         Examples
         --------
@@ -53,7 +53,7 @@ class GeneralizedQSamplingModel(OdfModel, Cache):
 
         >>> from dipy.data import dsi_voxels
         >>> data, gtab = dsi_voxels()
-        >>> from dipy.core.subdivide_octahedron import create_unit_sphere 
+        >>> from dipy.core.subdivide_octahedron import create_unit_sphere
         >>> sphere = create_unit_sphere(5)
         >>> from dipy.reconst.gqi import GeneralizedQSamplingModel
         >>> gq = GeneralizedQSamplingModel(gtab, 'gqi2', 1.1)
@@ -75,7 +75,7 @@ class GeneralizedQSamplingModel(OdfModel, Cache):
         scaling = np.sqrt(self.gtab.bvals * 0.01506)
         tmp = np.tile(scaling, (3, 1))
         gradsT = self.gtab.bvecs.T
-        b_vector = gradsT * tmp # element-wise product
+        b_vector = gradsT * tmp  # element-wise product
         self.b_vector = b_vector.T
 
     @multi_voxel_fit
@@ -109,18 +109,22 @@ class GeneralizedQSamplingFit(OdfFit):
         self.gqi_vector = self.model.cache_get('gqi_vector', key=sphere)
         if self.gqi_vector is None:
             if self.model.method == 'gqi2':
-                H=squared_radial_component
-                #print self.gqi_vector.shape
-                self.gqi_vector = np.real(H(np.dot(self.model.b_vector,                                         sphere.vertices.T) * self.model.Lambda))
+                H = squared_radial_component
+                # print self.gqi_vector.shape
+                self.gqi_vector = np.real(H(np.dot(
+                    self.model.b_vector, sphere.vertices.T) *
+                    self.model.Lambda))
             if self.model.method == 'standard':
-                self.gqi_vector = np.real(np.sinc(np.dot(self.model.b_vector,                                   sphere.vertices.T) * self.model.Lambda / np.pi))
+                self.gqi_vector = np.real(np.sinc(np.dot(
+                    self.model.b_vector, sphere.vertices.T) *
+                    self.model.Lambda / np.pi))
             self.model.cache_set('gqi_vector', sphere, self.gqi_vector)
 
         return np.dot(self.data, self.gqi_vector)
 
 
 def normalize_qa(qa, max_qa=None):
-    """ Normalize quantitative anisotropy. 
+    """ Normalize quantitative anisotropy.
 
     Used mostly with GQI rather than GQI2.
 
@@ -139,8 +143,8 @@ def normalize_qa(qa, max_qa=None):
     Notes
     -----
     Normalized quantitative anisotropy has the very useful property
-    to be very small near gray matter and background areas. Therefore, 
-    it can be used to mask out white matter areas. 
+    to be very small near gray matter and background areas. Therefore,
+    it can be used to mask out white matter areas.
 
     """
     if max_qa is None:
@@ -165,15 +169,19 @@ def npa(self, odf, width=5):
 
     Nimmo-Smith et. al  ISMRM 2011
     """
-    #odf = self.odf(s)
+    # odf = self.odf(s)
     t0, t1, t2 = triple_odf_maxima(self.odf_vertices, odf, width)
     psi0 = t0[1] ** 2
     psi1 = t1[1] ** 2
     psi2 = t2[1] ** 2
-    npa = np.sqrt((psi0 - psi1) ** 2 + (psi1 - psi2) ** 2 + (psi2 - psi0) ** 2) / np.sqrt(2 * (psi0 ** 2 + psi1 ** 2 + psi2 ** 2))
-    #print 'tom >>>> ',t0,t1,t2,npa
+    npa = (np.sqrt(
+        (psi0 - psi1) ** 2 +
+        (psi1 - psi2) ** 2 +
+        (psi2 - psi0) ** 2) /
+        np.sqrt(2 * (psi0 ** 2 + psi1 ** 2 + psi2 ** 2)))
+    # print 'tom >>>> ',t0,t1,t2,npa
 
-    return t0,t1,t2,npa
+    return t0, t1, t2, npa
 
 
 def equatorial_zone_vertices(vertices, pole, width=5):
@@ -181,7 +189,9 @@ def equatorial_zone_vertices(vertices, pole, width=5):
     finds the 'vertices' in the equatorial zone conjugate
     to 'pole' with width half 'width' degrees
     """
-    return [i for i,v in enumerate(vertices) if np.abs(np.dot(v,pole)) < np.abs(np.sin(np.pi*width/180))]
+    return [i
+            for i, v in enumerate(vertices)
+            if np.abs(np.dot(v, pole)) < np.abs(np.sin(np.pi * width / 180))]
 
 
 def polar_zone_vertices(vertices, pole, width=5):
@@ -189,7 +199,9 @@ def polar_zone_vertices(vertices, pole, width=5):
     finds the 'vertices' in the equatorial band around
     the 'pole' of radius 'width' degrees
     """
-    return [i for i,v in enumerate(vertices) if np.abs(np.dot(v,pole)) > np.abs(np.cos(np.pi*width/180))]
+    return [i
+            for i, v in enumerate(vertices)
+            if np.abs(np.dot(v, pole)) > np.abs(np.cos(np.pi * width / 180))]
 
 
 def upper_hemi_map(v):
@@ -201,9 +213,10 @@ def upper_hemi_map(v):
 
 def equatorial_maximum(vertices, odf, pole, width):
     eqvert = equatorial_zone_vertices(vertices, pole, width)
-    #need to test for whether eqvert is empty or not
+    # need to test for whether eqvert is empty or not
     if len(eqvert) == 0:
-        print('empty equatorial band at %s  pole with width %f' % (np.array_str(pole), width))
+        print('empty equatorial band at %s  pole with width %f' %
+              (np.array_str(pole), width))
         return None, None
     eqvals = [odf[i] for i in eqvert]
     eqargmax = np.argmax(eqvals)
@@ -213,18 +226,21 @@ def equatorial_maximum(vertices, odf, pole, width):
     return eqvertmax, eqvalmax
 
 
-def patch_vertices(vertices,pole, width):
+def patch_vertices(vertices, pole, width):
     """
     find 'vertices' within the cone of 'width' degrees around 'pole'
     """
-    return [i for i,v in enumerate(vertices) if np.abs(np.dot(v,pole)) > np.abs(np.cos(np.pi*width/180))]
+    return [i
+            for i, v in enumerate(vertices)
+            if np.abs(np.dot(v, pole)) > np.abs(np.cos(np.pi * width / 180))]
 
 
 def patch_maximum(vertices, odf, pole, width):
     eqvert = patch_vertices(vertices, pole, width)
-    #need to test for whether eqvert is empty or not
+    # need to test for whether eqvert is empty or not
     if len(eqvert) == 0:
-        print('empty cone around pole %s with with width %f' % (np.array_str(pole), width))
+        print('empty cone around pole %s with with width %f' %
+              (np.array_str(pole), width))
         return np.Null, np.Null
     eqvals = [odf[i] for i in eqvert]
     eqargmax = np.argmax(eqvals)
@@ -239,26 +255,27 @@ def odf_sum(odf):
 
 def patch_sum(vertices, odf, pole, width):
     eqvert = patch_vertices(vertices, pole, width)
-    #need to test for whether eqvert is empty or not
+    # need to test for whether eqvert is empty or not
     if len(eqvert) == 0:
-        print('empty cone around pole %s with with width %f' % (np.array_str(pole), width))
+        print('empty cone around pole %s with with width %f' %
+              (np.array_str(pole), width))
         return np.Null
     return np.sum([odf[i] for i in eqvert])
 
 
 def triple_odf_maxima(vertices, odf, width):
 
-    indmax1 = np.argmax([odf[i] for i,v in enumerate(vertices)])
+    indmax1 = np.argmax([odf[i] for i, v in enumerate(vertices)])
     odfmax1 = odf[indmax1]
     pole = vertices[indmax1]
     eqvert = equatorial_zone_vertices(vertices, pole, width)
-    indmax2, odfmax2 = equatorial_maximum(vertices,\
-                                              odf, pole, width)
-    indmax3 = eqvert[np.argmin([np.abs(np.dot(vertices[indmax2],vertices[p])) for p in eqvert])]
+    indmax2, odfmax2 = equatorial_maximum(vertices, odf, pole, width)
+    indmax3 = eqvert[np.argmin([np.abs(np.dot(vertices[indmax2], vertices[p]))
+                                for p in eqvert])]
     odfmax3 = odf[indmax3]
     """
     cross12 = np.cross(vertices[indmax1],vertices[indmax2])
     cross12 = cross12/np.sqrt(np.sum(cross12**2))
     indmax3, odfmax3 = patch_maximum(vertices, odf, cross12, 2*width)
     """
-    return [(indmax1, odfmax1),(indmax2, odfmax2),(indmax3, odfmax3)]
+    return [(indmax1, odfmax1), (indmax2, odfmax2), (indmax3, odfmax3)]
