@@ -16,34 +16,36 @@ from dipy.direction.peaks import peak_directions
 
 
 def test_gqi():
-    #load symmetric 724 sphere
+    # load symmetric 724 sphere
     sphere = get_sphere('symmetric724')
-    #load icosahedron sphere
+    # load icosahedron sphere
     sphere2 = create_unit_sphere(5)
     btable = np.loadtxt(get_data('dsi515btable'))
-    bvals = btable[:,0]
-    bvecs = btable[:,1:]
+    bvals = btable[:, 0]
+    bvecs = btable[:, 1:]
     gtab = gradient_table(bvals, bvecs)
     data, golden_directions = SticksAndBall(gtab, d=0.0015,
-                               S0=100, angles=[(0, 0), (90, 0)],
-                               fractions=[50, 50], snr=None)
+                                            S0=100, angles=[(0, 0), (90, 0)],
+                                            fractions=[50, 50], snr=None)
     gq = GeneralizedQSamplingModel(gtab, method='gqi2', sampling_length=1.4)
 
-    #symmetric724
+    # symmetric724
     gqfit = gq.fit(data)
     odf = gqfit.odf(sphere)
     directions, values, indices = peak_directions(odf, sphere, .35, 25)
     assert_equal(len(directions), 2)
-    assert_almost_equal(angular_similarity(directions, golden_directions), 2, 1)
+    assert_almost_equal(angular_similarity(directions, golden_directions), 2,
+                        1)
 
-    #5 subdivisions
+    # 5 subdivisions
     gqfit = gq.fit(data)
     odf2 = gqfit.odf(sphere2)
     directions, values, indices = peak_directions(odf2, sphere2, .35, 25)
     assert_equal(len(directions), 2)
-    assert_almost_equal(angular_similarity(directions, golden_directions), 2, 1)
+    assert_almost_equal(angular_similarity(directions, golden_directions), 2,
+                        1)
 
-    sb_dummies=sticks_and_ball_dummies(gtab)
+    sb_dummies = sticks_and_ball_dummies(gtab)
     for sbd in sb_dummies:
         data, golden_directions = sb_dummies[sbd]
         odf = gq.fit(data).odf(sphere2)
