@@ -1,13 +1,12 @@
 import numpy as np
 from dipy.data import get_sphere, get_3shell_gtab, get_isbi2013_2shell_gtab
 from dipy.reconst.shore import ShoreModel
-from dipy.reconst.shm import QballModel, sh_to_sf
-from dipy.direction.peaks import gfa, peak_directions
+from dipy.reconst.shm import sh_to_sf
+from dipy.direction.peaks import peak_directions
+from dipy.reconst.odf import gfa
 from numpy.testing import (assert_equal,
                            assert_almost_equal,
-                           run_module_suite,
-                           assert_array_equal,
-                           assert_raises)
+                           run_module_suite)
 from dipy.sims.voxel import SticksAndBall
 from dipy.core.subdivide_octahedron import create_unit_sphere
 from dipy.core.sphere_stats import angular_similarity
@@ -34,15 +33,14 @@ def test_shore_odf():
     odf_from_sh = sh_to_sf(odf_sh, sphere, 6, basis_type=None)
     assert_almost_equal(odf, odf_from_sh, 10)
 
-
-    directions, _ , _ = peak_directions(odf, sphere, .35, 25)
+    directions, _, _ = peak_directions(odf, sphere, .35, 25)
     assert_equal(len(directions), 2)
     assert_almost_equal(
         angular_similarity(directions, golden_directions), 2, 1)
 
     # 5 subdivisions
     odf = asmfit.odf(sphere2)
-    directions, _ , _ = peak_directions(odf, sphere2, .35, 25)
+    directions, _, _ = peak_directions(odf, sphere2, .35, 25)
     assert_equal(len(directions), 2)
     assert_almost_equal(
         angular_similarity(directions, golden_directions), 2, 1)
