@@ -10,7 +10,7 @@ from scipy.ndimage.filters import median_filter
 try:
     from skimage.filters import threshold_otsu as otsu
 except:
-    from .threshold import otsu
+    from dipy.segment.threshold import otsu
 
 from scipy.ndimage import binary_dilation, generate_binary_structure
 
@@ -32,8 +32,6 @@ def multi_median(input, median_radius, numpass):
     input : ndarray
         Filtered input volume.
     """
-    outvol = np.zeros_like(input)
-
     # Array representing the size of the median window in each dimension.
     medarr = np.ones_like(input.shape) * ((median_radius * 2) + 1)
 
@@ -234,7 +232,8 @@ def segment_from_cfa(tensor_fit, roi, threshold, return_cfa=False):
         A binary mask, which contains the bounding box for the segmentation.
 
     threshold : array-like
-        An iterable that defines the min and max values to use for the thresholding.
+        An iterable that defines the min and max values to use for the
+        thresholding.
         The values are specified as (R_min, R_max, G_min, G_max, B_min, B_max)
 
     return_cfa : bool, optional
@@ -258,7 +257,9 @@ def segment_from_cfa(tensor_fit, roi, threshold, return_cfa=False):
     cfa = color_fa(FA, tensor_fit.evecs)
     roi = np.asarray(roi, dtype=bool)
 
-    include = (cfa >= threshold[0::2]) & (cfa <= threshold[1::2]) & roi[..., None]
+    include = ((cfa >= threshold[0::2]) &
+               (cfa <= threshold[1::2]) &
+               roi[..., None])
     mask = np.all(include, axis=-1)
 
     if return_cfa:
@@ -266,9 +267,11 @@ def segment_from_cfa(tensor_fit, roi, threshold, return_cfa=False):
 
     return mask
 
+
 def clean_cc_mask(mask):
     """
-    Cleans a segmentation of the corpus callosum so no random pixels are included.
+    Cleans a segmentation of the corpus callosum so no random pixels
+    are included.
 
     Parameters
     ----------
@@ -288,7 +291,8 @@ def clean_cc_mask(mask):
     # Flood fill algorithm to find contiguous regions.
     labels, numL = label(mask)
 
-    volumes = [len(labels[np.where(labels == l_idx+1)]) for l_idx in np.arange(numL)]
+    volumes = [len(labels[np.where(labels == l_idx+1)])
+               for l_idx in np.arange(numL)]
     biggest_vol = np.arange(numL)[np.where(volumes == np.max(volumes))] + 1
     new_cc_mask[np.where(labels == biggest_vol)] = 1
 
