@@ -2,13 +2,15 @@ import numpy as np
 import dipy.segment.metric as dipymetric
 import itertools
 
-from nose.tools import assert_true, assert_false, assert_equal, assert_almost_equal
-from numpy.testing import assert_array_equal, assert_raises, run_module_suite
+from nose.tools import (assert_true, assert_false, assert_equal)
+from numpy.testing import (assert_array_equal, assert_raises, run_module_suite,
+                           assert_almost_equal)
 
 
 def norm(x, ord=None, axis=None):
     if axis is not None:
-        return np.apply_along_axis(np.linalg.norm, axis, x.astype(np.float64), ord)
+        return np.apply_along_axis(np.linalg.norm, axis,
+                                   x.astype(np.float64), ord)
 
     return np.linalg.norm(x.astype(np.float64), ord=ord)
 
@@ -36,7 +38,8 @@ def test_metric_minimum_average_direct_flip():
 
     class MinimumAverageDirectFlipMetric(dipymetric.Metric):
         def __init__(self, feature):
-            super(MinimumAverageDirectFlipMetric, self).__init__(feature=feature)
+            super(MinimumAverageDirectFlipMetric, self).__init__(
+                    feature=feature)
 
         @property
         def is_order_invariant(self):
@@ -46,7 +49,8 @@ def test_metric_minimum_average_direct_flip():
             return shape1[0] == shape2[0]
 
         def dist(self, v1, v2):
-            average_euclidean = lambda x, y: np.mean(norm(x-y, axis=1))
+            def average_euclidean(x, y):
+                return np.mean(norm(x-y, axis=1))
             dist_direct = average_euclidean(v1, v2)
             dist_flipped = average_euclidean(v1, v2[::-1])
             return min(dist_direct, dist_flipped)
@@ -78,19 +82,24 @@ def test_metric_minimum_average_direct_flip():
         s_zero_mean = s - s_mean
         s_rotated = np.dot(M_rotation, s_zero_mean.T).T + s_mean
 
-        opposite = norm(np.cross(rot_axis, s_zero_mean), axis=1) / norm(rot_axis)
-        distances = np.sqrt(2*opposite**2 * (1 - np.cos(60.*np.pi/180.))).astype(dtype)
+        opposite = norm(np.cross(rot_axis, s_zero_mean),
+                        axis=1) / norm(rot_axis)
+        distances = np.sqrt(2*opposite**2 *
+                            (1 - np.cos(60.*np.pi/180.))).astype(dtype)
         d = np.mean(distances)
         assert_almost_equal(metric.dist(s, s_rotated), d, 5)
 
-        for s1, s2 in itertools.product(*[streamlines]*2):  # All possible pairs
-            # Extract features since metric doesn't work directly on streamlines
+        # All possible pairs
+        for s1, s2 in itertools.product(*[streamlines]*2):
+            # Extract features since metric doesn't work
+            # directly on streamlines
             f1 = metric.feature.extract(s1)
             f2 = metric.feature.extract(s2)
 
             # Test method are_compatible
             same_nb_points = f1.shape[0] == f2.shape[0]
-            assert_equal(metric.are_compatible(f1.shape, f2.shape), same_nb_points)
+            assert_equal(metric.are_compatible(f1.shape, f2.shape),
+                         same_nb_points)
 
             # Test method dist if features are compatible
             if metric.are_compatible(f1.shape, f2.shape):
@@ -104,7 +113,8 @@ def test_metric_minimum_average_direct_flip():
 
         # This metric type is order invariant
         assert_true(metric.is_order_invariant)
-        for s1, s2 in itertools.product(*[streamlines]*2):  # All possible pairs
+        # All possible pairs
+        for s1, s2 in itertools.product(*[streamlines]*2):
             f1 = metric.feature.extract(s1)
             f2 = metric.feature.extract(s2)
 
@@ -159,8 +169,10 @@ def test_metric_cosine():
         assert_equal(metric.dist(v1, v2), 0.5)  # orthogonal
         assert_equal(metric.dist(v1, v3), 1.)   # opposite
 
-        for s1, s2 in itertools.product(*[streamlines]*2):  # All possible pairs
-            # Extract features since metric doesn't work directly on streamlines
+        # All possible pairs
+        for s1, s2 in itertools.product(*[streamlines]*2):
+            # Extract features since metric doesn't
+            # work directly on streamlines
             f1 = metric.feature.extract(s1)
             f2 = metric.feature.extract(s2)
 
@@ -182,7 +194,8 @@ def test_metric_cosine():
 
         # This metric type is not order invariant
         assert_false(metric.is_order_invariant)
-        for s1, s2 in itertools.product(*[streamlines]*2):  # All possible pairs
+        # All possible pairs
+        for s1, s2 in itertools.product(*[streamlines]*2):
             f1 = metric.feature.extract(s1)
             f2 = metric.feature.extract(s2)
 
@@ -226,7 +239,8 @@ def test_distance_matrix():
 
         for i in range(len(data)):
             for j in range(len(data)):
-                assert_equal(D[i, j], dipymetric.dist(metric, data[i], data[j]))
+                assert_equal(D[i, j], dipymetric.dist(metric, data[i],
+                                                      data[j]))
 
         # Compute distances of all tuples spawn by the Cartesian product
         # of `data` with `data2`.
@@ -236,7 +250,8 @@ def test_distance_matrix():
 
         for i in range(len(data)):
             for j in range(len(data2)):
-                assert_equal(D[i, j], dipymetric.dist(metric, data[i], data2[j]))
+                assert_equal(D[i, j], dipymetric.dist(metric, data[i],
+                                                      data2[j]))
 
 
 if __name__ == '__main__':
