@@ -10,7 +10,7 @@ from nose.tools import (assert_true, assert_false, assert_raises,
                         assert_equal, assert_not_equal)
 
 
-from ..decorators import doctest_skip_parser
+from dipy.testing.decorators import doctest_skip_parser
 
 
 def test_skipper():
