@@ -1,17 +1,21 @@
 from __future__ import print_function
 
+import types
+
 import numpy as np
 from numpy.linalg import norm
 import numpy.testing as npt
 from dipy.testing.memory import get_type_refcount
+from dipy.testing import assert_arrays_equal
 
 from nose.tools import assert_true, assert_equal, assert_almost_equal
 from numpy.testing import (assert_array_equal, assert_array_almost_equal,
                            assert_raises, run_module_suite)
 
+from dipy.tracking import Streamlines
 import dipy.tracking.utils as ut
 from dipy.tracking.streamline import (set_number_of_points,
-                                      length as ds_length,
+                                      length,
                                       relist_streamlines,
                                       unlist_streamlines,
                                       center_streamlines,
@@ -194,49 +198,61 @@ def set_number_of_points_python(xyz, n_pols=3):
 def test_set_number_of_points():
     # Test resampling of only one streamline
     nb_points = 12
-    modified_streamline_cython = set_number_of_points(
+    new_streamline_cython = set_number_of_points(
         streamline, nb_points)
-    modified_streamline_python = set_number_of_points_python(
+    new_streamline_python = set_number_of_points_python(
         streamline, nb_points)
-    assert_equal(len(modified_streamline_cython), nb_points)
+    assert_equal(len(new_streamline_cython), nb_points)
     # Using a 5 digits precision because of streamline is in float32.
-    assert_array_almost_equal(modified_streamline_cython,
-                              modified_streamline_python, 5)
+    assert_array_almost_equal(new_streamline_cython,
+                              new_streamline_python, 5)
 
-    modified_streamline_cython = set_number_of_points(
+    new_streamline_cython = set_number_of_points(
         streamline_64bit, nb_points)
-    modified_streamline_python = set_number_of_points_python(
+    new_streamline_python = set_number_of_points_python(
         streamline_64bit, nb_points)
-    assert_equal(len(modified_streamline_cython), nb_points)
-    assert_array_almost_equal(modified_streamline_cython,
-                              modified_streamline_python)
+    assert_equal(len(new_streamline_cython), nb_points)
+    assert_array_almost_equal(new_streamline_cython,
+                              new_streamline_python)
 
     res = []
     simple_streamline = np.array([[0, 0, 0], [1, 1, 1], [2, 2, 2]], 'f4')
     for nb_points in range(2, 200):
-        modified_streamline_cython = set_number_of_points(
+        new_streamline_cython = set_number_of_points(
             simple_streamline, nb_points)
-        res.append(nb_points - len(modified_streamline_cython))
+        res.append(nb_points - len(new_streamline_cython))
     assert_equal(np.sum(res), 0)
 
     # Test resampling of multiple streamlines of different nb_points
     nb_points = 12
-    modified_streamlines_cython = set_number_of_points(
+    new_streamlines_cython = set_number_of_points(
         streamlines, nb_points)
 
     for i, s in enumerate(streamlines):
-        modified_streamline_python = set_number_of_points_python(s, nb_points)
+        new_streamline_python = set_number_of_points_python(s, nb_points)
         # Using a 5 digits precision because of streamline is in float32.
-        assert_array_almost_equal(modified_streamlines_cython[i],
-                                  modified_streamline_python, 5)
+        assert_array_almost_equal(new_streamlines_cython[i],
+                                  new_streamline_python, 5)
 
-    modified_streamlines_cython = set_number_of_points(
+    # ArraySequence
+    arrseq = Streamlines(streamlines)
+    new_streamlines_as_seq_cython = set_number_of_points(arrseq, nb_points)
+    assert_array_almost_equal(new_streamlines_as_seq_cython,
+                              new_streamlines_cython)
+
+    new_streamlines_cython = set_number_of_points(
         streamlines_64bit, nb_points)
 
     for i, s in enumerate(streamlines_64bit):
-        modified_streamline_python = set_number_of_points_python(s, nb_points)
-        assert_array_almost_equal(modified_streamlines_cython[i],
-                                  modified_streamline_python)
+        new_streamline_python = set_number_of_points_python(s, nb_points)
+        assert_array_almost_equal(new_streamlines_cython[i],
+                                  new_streamline_python)
+
+    # ArraySequence
+    arrseq = Streamlines(streamlines_64bit)
+    new_streamlines_as_seq_cython = set_number_of_points(arrseq, nb_points)
+    assert_array_almost_equal(new_streamlines_as_seq_cython,
+                              new_streamlines_cython)
 
     # Test streamlines with mixed dtype
     streamlines_mixed_dtype = [streamline,
@@ -249,19 +265,19 @@ def test_set_number_of_points():
                        [nb_points] * len(streamlines_mixed_dtype))
 
     # Test streamlines with different shape
-    modified_streamlines_cython = set_number_of_points(
+    new_streamlines_cython = set_number_of_points(
         heterogeneous_streamlines, nb_points)
 
     for i, s in enumerate(heterogeneous_streamlines):
-        modified_streamline_python = set_number_of_points_python(s, nb_points)
-        assert_array_almost_equal(modified_streamlines_cython[i],
-                                  modified_streamline_python)
+        new_streamline_python = set_number_of_points_python(s, nb_points)
+        assert_array_almost_equal(new_streamlines_cython[i],
+                                  new_streamline_python)
 
     # Test streamline with integer dtype
-    modified_streamline = set_number_of_points(streamline.astype(np.int32))
-    assert_true(modified_streamline.dtype == np.float32)
-    modified_streamline = set_number_of_points(streamline.astype(np.int64))
-    assert_true(modified_streamline.dtype == np.float64)
+    new_streamline = set_number_of_points(streamline.astype(np.int32))
+    assert_true(new_streamline.dtype == np.float32)
+    new_streamline = set_number_of_points(streamline.astype(np.int64))
+    assert_true(new_streamline.dtype == np.float64)
 
     # Test empty list
     assert_equal(set_number_of_points([]), [])
@@ -271,7 +287,8 @@ def test_set_number_of_points():
 
     # We do not support list of lists, it should be numpy ndarray.
     streamline_unsupported = [[1, 2, 3], [4, 5, 5], [2, 1, 3], [4, 2, 1]]
-    assert_raises(AttributeError, set_number_of_points, streamline_unsupported)
+    assert_raises(AttributeError,
+                  set_number_of_points, streamline_unsupported)
 
     # Test setting number of points of a numpy with flag WRITABLE=False
     streamline_readonly = streamline.copy()
@@ -285,7 +302,8 @@ def test_set_number_of_points():
         streamlines_readonly.append(s.copy())
         streamlines_readonly[-1].setflags(write=False)
 
-    assert_equal(len(set_number_of_points(streamlines_readonly, nb_points=42)),
+    assert_equal(len(set_number_of_points(streamlines_readonly,
+                                          nb_points=42)),
                  len(streamlines_readonly))
 
     streamlines_readonly = []
@@ -293,9 +311,14 @@ def test_set_number_of_points():
         streamlines_readonly.append(s.copy())
         streamlines_readonly[-1].setflags(write=False)
 
-    assert_equal(len(set_number_of_points(streamlines_readonly, nb_points=42)),
+    assert_equal(len(set_number_of_points(streamlines_readonly,
+                                          nb_points=42)),
                  len(streamlines_readonly))
 
+    # Test if nb_points is less than 2
+    assert_raises(ValueError, set_number_of_points, [np.ones((10, 3)),
+                  np.ones((10, 3))], nb_points=1)
+
 
 def test_set_number_of_points_memory_leaks():
     # Test some dtypes
@@ -303,16 +326,18 @@ def test_set_number_of_points_memory_leaks():
     for dtype in dtypes:
         rng = np.random.RandomState(1234)
         NB_STREAMLINES = 10000
-        streamlines = [rng.randn(rng.randint(10, 100), 3).astype(dtype) for _ in range(NB_STREAMLINES)]
+        streamlines = [rng.randn(rng.randint(10, 100), 3).astype(dtype)
+                       for _ in range(NB_STREAMLINES)]
 
         list_refcount_before = get_type_refcount()["list"]
 
         rstreamlines = set_number_of_points(streamlines, nb_points=2)
         list_refcount_after = get_type_refcount()["list"]
-        del rstreamlines  # Delete `rstreamlines` because it holds a reference to `list`.
+        del rstreamlines  # Delete `rstreamlines` because it holds a reference
+        #                   to `list`.
 
-        # Calling `set_number_of_points` should increase the refcount of `list` by one
-        # since we kept the returned value.
+        # Calling `set_number_of_points` should increase the refcount of `list`
+        #  by one since we kept the returned value.
         assert_equal(list_refcount_after, list_refcount_before+1)
 
     # Test mixed dtypes
@@ -328,48 +353,79 @@ def test_set_number_of_points_memory_leaks():
     rstreamlines = set_number_of_points(streamlines, nb_points=2)
     list_refcount_after = get_type_refcount()["list"]
 
-    # Calling `set_number_of_points` should increase the refcount of `list` by one
-    # since we kept the returned value.
+    # Calling `set_number_of_points` should increase the refcount of `list`
+    #  by one since we kept the returned value.
     assert_equal(list_refcount_after, list_refcount_before+1)
 
 
 def test_length():
     # Test length of only one streamline
-    length_streamline_cython = ds_length(streamline)
+    length_streamline_cython = length(streamline)
     length_streamline_python = length_python(streamline)
     assert_almost_equal(length_streamline_cython, length_streamline_python)
 
-    length_streamline_cython = ds_length(streamline_64bit)
+    length_streamline_cython = length(streamline_64bit)
     length_streamline_python = length_python(streamline_64bit)
     assert_almost_equal(length_streamline_cython, length_streamline_python)
 
     # Test computing length of multiple streamlines of different nb_points
-    length_streamlines_cython = ds_length(streamlines)
+    length_streamlines_cython = length(streamlines)
 
     for i, s in enumerate(streamlines):
         length_streamline_python = length_python(s)
         assert_array_almost_equal(length_streamlines_cython[i],
                                   length_streamline_python)
 
-    length_streamlines_cython = ds_length(streamlines_64bit)
+    length_streamlines_cython = length(streamlines_64bit)
 
     for i, s in enumerate(streamlines_64bit):
         length_streamline_python = length_python(s)
         assert_array_almost_equal(length_streamlines_cython[i],
                                   length_streamline_python)
 
+    # ArraySequence
+    # Test length of only one streamline
+    length_streamline_cython = length(streamline_64bit)
+    length_streamline_arrseq = length(Streamlines([streamline]))
+    assert_almost_equal(length_streamline_arrseq, length_streamline_cython)
+
+    length_streamline_cython = length(streamline_64bit)
+    length_streamline_arrseq = length(Streamlines([streamline_64bit]))
+    assert_almost_equal(length_streamline_arrseq, length_streamline_cython)
+
+    # Test computing length of multiple streamlines of different nb_points
+    length_streamlines_cython = length(streamlines)
+    length_streamlines_arrseq = length(Streamlines(streamlines))
+    assert_array_almost_equal(length_streamlines_arrseq,
+                              length_streamlines_cython)
+
+    length_streamlines_cython = length(streamlines_64bit)
+    length_streamlines_arrseq = length(Streamlines(streamlines_64bit))
+    assert_array_almost_equal(length_streamlines_arrseq,
+                              length_streamlines_cython)
+
+    # Test on a sliced ArraySequence
+    length_streamlines_cython = length(streamlines_64bit[::2])
+    length_streamlines_arrseq = length(Streamlines(streamlines_64bit)[::2])
+    assert_array_almost_equal(length_streamlines_arrseq,
+                              length_streamlines_cython)
+    length_streamlines_cython = length(streamlines[::-1])
+    length_streamlines_arrseq = length(Streamlines(streamlines)[::-1])
+    assert_array_almost_equal(length_streamlines_arrseq,
+                              length_streamlines_cython)
+
     # Test streamlines having mixed dtype
     streamlines_mixed_dtype = [streamline,
                                streamline.astype(np.float64),
                                streamline.astype(np.int32),
                                streamline.astype(np.int64)]
-    lengths_mixed_dtype = [ds_length(s)
+    lengths_mixed_dtype = [length(s)
                            for s in streamlines_mixed_dtype]
-    assert_array_equal(ds_length(streamlines_mixed_dtype),
+    assert_array_equal(length(streamlines_mixed_dtype),
                        lengths_mixed_dtype)
 
     # Test streamlines with different shape
-    length_streamlines_cython = ds_length(
+    length_streamlines_cython = length(
         heterogeneous_streamlines)
 
     for i, s in enumerate(heterogeneous_streamlines):
@@ -378,18 +434,18 @@ def test_length():
                                   length_streamline_python)
 
     # Test streamline having integer dtype
-    length_streamline = ds_length(streamline.astype('int'))
+    length_streamline = length(streamline.astype('int'))
     assert_true(length_streamline.dtype == np.float64)
 
     # Test empty list
-    assert_equal(ds_length([]), 0.0)
+    assert_equal(length([]), 0.0)
 
     # Test streamline having only one point
-    assert_equal(ds_length(np.array([[1, 2, 3]])), 0.0)
+    assert_equal(length(np.array([[1, 2, 3]])), 0.0)
 
     # We do not support list of lists, it should be numpy ndarray.
     streamline_unsupported = [[1, 2, 3], [4, 5, 5], [2, 1, 3], [4, 2, 1]]
-    assert_raises(AttributeError, ds_length,
+    assert_raises(AttributeError, length,
                   streamline_unsupported)
 
     # Test setting computing length of a numpy with flag WRITABLE=False
@@ -398,14 +454,14 @@ def test_length():
         streamlines_readonly.append(s.copy())
         streamlines_readonly[-1].setflags(write=False)
 
-    assert_array_almost_equal(ds_length(streamlines_readonly),
+    assert_array_almost_equal(length(streamlines_readonly),
                               [length_python(s) for s in streamlines_readonly])
     streamlines_readonly = []
     for s in streamlines_64bit:
         streamlines_readonly.append(s.copy())
         streamlines_readonly[-1].setflags(write=False)
 
-    assert_array_almost_equal(ds_length(streamlines_readonly),
+    assert_array_almost_equal(length(streamlines_readonly),
                               [length_python(s) for s in streamlines_readonly])
 
 
@@ -415,14 +471,15 @@ def test_length_memory_leaks():
     for dtype in dtypes:
         rng = np.random.RandomState(1234)
         NB_STREAMLINES = 10000
-        streamlines = [rng.randn(rng.randint(10, 100), 3).astype(dtype) for _ in range(NB_STREAMLINES)]
+        streamlines = [rng.randn(rng.randint(10, 100), 3).astype(dtype)
+                       for _ in range(NB_STREAMLINES)]
 
         list_refcount_before = get_type_refcount()["list"]
 
-        lengths = ds_length(streamlines)
+        lengths = length(streamlines)
         list_refcount_after = get_type_refcount()["list"]
 
-        # Calling `ds_length` shouldn't increase the refcount of `list`
+        # Calling `length` shouldn't increase the refcount of `list`
         # since the return value is a numpy array.
         assert_equal(list_refcount_after, list_refcount_before)
 
@@ -436,10 +493,10 @@ def test_length_memory_leaks():
 
     list_refcount_before = get_type_refcount()["list"]
 
-    lengths = ds_length(streamlines)
+    lengths = length(streamlines)
     list_refcount_after = get_type_refcount()["list"]
 
-    # Calling `ds_length` shouldn't increase the refcount of `list`
+    # Calling `length` shouldn't increase the refcount of `list`
     # since the return value is a numpy array.
     assert_equal(list_refcount_after, list_refcount_before)
 
@@ -635,16 +692,18 @@ def test_compress_streamlines_memory_leaks():
     for dtype in dtypes:
         rng = np.random.RandomState(1234)
         NB_STREAMLINES = 10000
-        streamlines = [rng.randn(rng.randint(10, 100), 3).astype(dtype) for _ in range(NB_STREAMLINES)]
+        streamlines = [rng.randn(rng.randint(10, 100), 3).astype(dtype)
+                       for _ in range(NB_STREAMLINES)]
 
         list_refcount_before = get_type_refcount()["list"]
 
         cstreamlines = compress_streamlines(streamlines)
         list_refcount_after = get_type_refcount()["list"]
-        del cstreamlines  # Delete `cstreamlines` because it holds a reference to `list`.
+        del cstreamlines  # Delete `cstreamlines` because it holds a reference
+        #                   to `list`.
 
-        # Calling `compress_streamlines` should increase the refcount of `list` by one
-        # since we kept the returned value.
+        # Calling `compress_streamlines` should increase the refcount of `list`
+        # by one since we kept the returned value.
         assert_equal(list_refcount_after, list_refcount_before+1)
 
     # Test mixed dtypes
@@ -660,10 +719,28 @@ def test_compress_streamlines_memory_leaks():
     cstreamlines = compress_streamlines(streamlines)
     list_refcount_after = get_type_refcount()["list"]
 
-    # Calling `compress_streamlines` should increase the refcount of `list` by one
-    # since we kept the returned value.
+    # Calling `compress_streamlines` should increase the refcount of `list` by
+    # one since we kept the returned value.
     assert_equal(list_refcount_after, list_refcount_before+1)
 
+
+def generate_sl(streamlines):
+    """
+    Helper function that takes a sequence and returns a generator
+
+    Parameters
+    ----------
+    streamlines : sequence
+        Usually, this would be a list of 2D arrays, representing streamlines
+
+    Returns
+    -------
+    generator
+    """
+    for sl in streamlines:
+        yield sl
+
+
 def test_select_by_rois():
     streamlines = [np.array([[0, 0., 0.9],
                              [1.9, 0., 0.]]),
@@ -682,62 +759,62 @@ def test_select_by_rois():
     selection = select_by_rois(streamlines, [mask1], [True],
                                tol=1)
 
-    npt.assert_array_equal(list(selection), [streamlines[0],
-                           streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[0],
+                        streamlines[1]])
 
     selection = select_by_rois(streamlines, [mask1, mask2], [True, True],
                                tol=1)
 
-    npt.assert_array_equal(list(selection), [streamlines[0],
-                           streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[0],
+                        streamlines[1]])
 
     selection = select_by_rois(streamlines, [mask1, mask2], [True, False])
 
-    npt.assert_array_equal(list(selection), [streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[1]])
 
     # Setting tolerance too low gets overridden:
     selection = select_by_rois(streamlines, [mask1, mask2], [True, False],
                                tol=0.1)
-    npt.assert_array_equal(list(selection), [streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[1]])
 
     selection = select_by_rois(streamlines, [mask1, mask2], [True, True],
                                tol=0.87)
 
-    npt.assert_array_equal(list(selection), [streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[1]])
 
     mask3 = np.zeros_like(mask1)
     mask3[0, 2, 2] = 1
     selection = select_by_rois(streamlines, [mask1, mask2, mask3],
                                [True, True, False], tol=1.0)
 
-    npt.assert_array_equal(list(selection), [streamlines[0]])
+    assert_arrays_equal(list(selection), [streamlines[0]])
 
     # Select using only one ROI
     selection = select_by_rois(streamlines, [mask1], [True], tol=0.87)
-    npt.assert_array_equal(list(selection), [streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[1]])
 
     selection = select_by_rois(streamlines, [mask1], [True], tol=1.0)
-    npt.assert_array_equal(list(selection), [streamlines[0],
-                           streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[0],
+                        streamlines[1]])
 
     # Use different modes:
     selection = select_by_rois(streamlines, [mask1, mask2, mask3],
                                [True, True, False],
                                mode="all",
                                tol=1.0)
-    npt.assert_array_equal(list(selection), [streamlines[0]])
+    assert_arrays_equal(list(selection), [streamlines[0]])
 
     selection = select_by_rois(streamlines, [mask1, mask2, mask3],
                                [True, True, False],
                                mode="either_end",
                                tol=1.0)
-    npt.assert_array_equal(list(selection), [streamlines[0]])
+    assert_arrays_equal(list(selection), [streamlines[0]])
 
     selection = select_by_rois(streamlines, [mask1, mask2, mask3],
                                [True, True, False],
                                mode="both_end",
                                tol=1.0)
-    npt.assert_array_equal(list(selection), [streamlines[0]])
+    assert_arrays_equal(list(selection), [streamlines[0]])
 
     mask2[0, 2, 2] = True
     selection = select_by_rois(streamlines, [mask1, mask2, mask3],
@@ -745,18 +822,14 @@ def test_select_by_rois():
                                mode="both_end",
                                tol=1.0)
 
-    npt.assert_array_equal(list(selection), [streamlines[0],
-                                             streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[0],
+                                          streamlines[1]])
 
     # Test with generator input:
-    def generate_sl(streamlines):
-        for sl in streamlines:
-            yield sl
-
     selection = select_by_rois(generate_sl(streamlines), [mask1], [True],
                                tol=1.0)
-    npt.assert_array_equal(list(selection), [streamlines[0],
-                           streamlines[1]])
+    assert_arrays_equal(list(selection), [streamlines[0],
+                        streamlines[1]])
 
 
 def test_orient_by_rois():
@@ -781,25 +854,103 @@ def test_orient_by_rois():
     # Transform the streamlines:
     x_streamlines = [sl + affine[:3, 3] for sl in streamlines]
 
-    for copy in [True, False]:
-        for sl, affine in zip([streamlines, x_streamlines], [None, affine]):
-            for mask1, mask2 in \
-              zip([mask1_vol, mask1_coords], [mask2_vol, mask2_coords]):
-                new_streamlines = orient_by_rois(sl, mask1, mask2,
-                                                 affine=affine, copy=copy)
-                if copy:
-                    flipped_sl = [sl[0], sl[1][::-1]]
-                else:
-                    flipped_sl = [np.array([[0, 0., 0],
-                                            [1, 0., 0.],
-                                            [2, 0., 0.]]),
-                                  np.array([[0, 0., 0.],
-                                            [1, 0., 0],
-                                            [2, 0,  0.]])]
-                    if affine is not None:
-                        flipped_sl = [s + affine[:3, 3] for s in flipped_sl]
+    # After reorientation, this should be the answer:
+    flipped_sl = [streamlines[0], streamlines[1][::-1]]
+    new_streamlines = orient_by_rois(streamlines,
+                                     mask1_vol,
+                                     mask2_vol,
+                                     in_place=False,
+                                     affine=None,
+                                     as_generator=False)
+    npt.assert_equal(new_streamlines, flipped_sl)
+    npt.assert_(new_streamlines is not streamlines)
 
-                npt.assert_equal(new_streamlines, flipped_sl)
+    # Test with affine:
+    x_flipped_sl = [s + affine[:3, 3] for s in flipped_sl]
+    new_streamlines = orient_by_rois(x_streamlines,
+                                     mask1_vol,
+                                     mask2_vol,
+                                     in_place=False,
+                                     affine=affine,
+                                     as_generator=False)
+    npt.assert_equal(new_streamlines, x_flipped_sl)
+    npt.assert_(new_streamlines is not x_streamlines)
+
+    # Test providing coord ROIs instead of vol ROIs:
+    new_streamlines = orient_by_rois(x_streamlines,
+                                     mask1_coords,
+                                     mask2_coords,
+                                     in_place=False,
+                                     affine=affine,
+                                     as_generator=False)
+    npt.assert_equal(new_streamlines, x_flipped_sl)
+
+    # Test with as_generator set to True
+    new_streamlines = orient_by_rois(streamlines,
+                                     mask1_vol,
+                                     mask2_vol,
+                                     in_place=False,
+                                     affine=None,
+                                     as_generator=True)
+
+    npt.assert_(isinstance(new_streamlines, types.GeneratorType))
+    ll = list(new_streamlines)
+    npt.assert_equal(ll, flipped_sl)
+
+    # Test with as_generator set to True and with the affine
+    new_streamlines = orient_by_rois(x_streamlines,
+                                     mask1_vol,
+                                     mask2_vol,
+                                     in_place=False,
+                                     affine=affine,
+                                     as_generator=True)
+
+    npt.assert_(isinstance(new_streamlines, types.GeneratorType))
+    ll = list(new_streamlines)
+    npt.assert_equal(ll, x_flipped_sl)
+
+    # Test with generator input:
+    new_streamlines = orient_by_rois(generate_sl(streamlines),
+                                     mask1_vol,
+                                     mask2_vol,
+                                     in_place=False,
+                                     affine=None,
+                                     as_generator=True)
+
+    npt.assert_(isinstance(new_streamlines, types.GeneratorType))
+    ll = list(new_streamlines)
+    npt.assert_equal(ll, flipped_sl)
+
+    # Generator output cannot take a True `in_place` kwarg:
+    npt.assert_raises(ValueError, orient_by_rois, *[generate_sl(streamlines),
+                                                    mask1_vol,
+                                                    mask2_vol],
+                      **dict(in_place=True,
+                             affine=None,
+                             as_generator=True))
+
+    # But you can input a generator and get a non-generator as output:
+    new_streamlines = orient_by_rois(generate_sl(streamlines),
+                                     mask1_vol,
+                                     mask2_vol,
+                                     in_place=False,
+                                     affine=None,
+                                     as_generator=False)
+
+    npt.assert_(not isinstance(new_streamlines, types.GeneratorType))
+    npt.assert_equal(new_streamlines, flipped_sl)
+
+    # Modify in-place:
+    new_streamlines = orient_by_rois(streamlines,
+                                     mask1_vol,
+                                     mask2_vol,
+                                     in_place=True,
+                                     affine=None,
+                                     as_generator=False)
+
+    npt.assert_equal(new_streamlines, flipped_sl)
+    # The two objects are one and the same:
+    npt.assert_(new_streamlines is streamlines)
 
 
 def test_values_from_volume():
