@@ -1,10 +1,9 @@
 from __future__ import division, print_function, absolute_import
 
-from ...utils.six.moves import xrange
+from dipy.utils.six.moves import xrange
 
 import numpy as np
 import nose
-import nibabel as nib
 
 from dipy.io.bvectxt import orientation_from_string
 from dipy.tracking.utils import (affine_for_trackvis, connectivity_matrix,
@@ -12,8 +11,10 @@ from dipy.tracking.utils import (affine_for_trackvis, connectivity_matrix,
                                  ndbincount, reduce_labels,
                                  reorder_voxels_affine, seeds_from_mask,
                                  random_seeds_from_mask, target,
-                                 _rmi, unique_rows, near_roi,
-                                 reduce_rois)
+                                 target_line_based, _rmi, unique_rows, near_roi,
+                                 reduce_rois, path_length, flexi_tvis_affine,
+                                 get_flexi_tvis_affine, _min_at)
+
 from dipy.tracking._utils import _to_voxel_coordinates
 
 import dipy.tracking.metrics as metrix
@@ -38,7 +39,7 @@ def make_streamlines():
 
 def test_density_map():
     # One streamline diagonal in volume
-    streamlines = [np.array([np.arange(10)]*3).T]
+    streamlines = [np.array([np.arange(10)] * 3).T]
     shape = (10, 10, 10)
     x = np.arange(10)
     expected = np.zeros(shape)
@@ -152,6 +153,7 @@ def test_ndbincount():
         assert_equal(bc[0, 1], expected[1])
         assert_equal(bc[1, 0], expected[2])
         assert_equal(bc[2, 2], expected[3])
+
     x = np.array([[0, 0], [0, 0], [0, 1], [0, 1], [1, 0], [2, 2]]).T
     expected = [2, 2, 1, 1]
     # count occurrences in x
@@ -175,10 +177,10 @@ def test_ndbincount():
 def test_reduce_labels():
     shape = (4, 5, 6)
     # labels from 100 to 220
-    labels = np.arange(100, np.prod(shape)+100).reshape(shape)
+    labels = np.arange(100, np.prod(shape) + 100).reshape(shape)
     # new labels form 0 to 120, and lookup maps range(0,120) to range(100, 220)
     new_labels, lookup = reduce_labels(labels)
-    assert_array_equal(new_labels, labels-100)
+    assert_array_equal(new_labels, labels - 100)
     assert_array_equal(lookup, labels.ravel())
 
 
@@ -192,7 +194,7 @@ def test_move_streamlines():
     affine[:3, 3] += (4, 5, 6)
     new_streamlines = move_streamlines(streamlines, affine)
     for i, test_sl in enumerate(new_streamlines):
-        assert_array_equal(test_sl, streamlines[i]+(4, 5, 6))
+        assert_array_equal(test_sl, streamlines[i] + (4, 5, 6))
 
     affine = np.eye(4)
     affine = affine[[2, 1, 0, 3]]
@@ -224,48 +226,63 @@ def test_target():
                    np.array([[0., 0., 0],
                              [0, 1., 1.],
                              [0, 2., 2.]])]
+    _target(target, streamlines, (0, 0, 0), (1, 0, 0), True)
+
+
+def test_target_lb():
+    streamlines = [np.array([[0., 1., 1.],
+                             [3., 1., 1.]]),
+                   np.array([[0., 0., 0.],
+                             [2., 2., 2.]]),
+                   np.array([[1., 1., 1.]])]  # Single-point streamline
+    _target(target_line_based, streamlines, (1, 1, 1), (2, 1, 1), False)
+
+
+def _target(target_f, streamlines, voxel_both_true, voxel_one_true,
+            test_bad_points):
     affine = np.eye(4)
     mask = np.zeros((4, 4, 4), dtype=bool)
-    mask[0, 0, 0] = True
 
     # Both pass though
-    new = list(target(streamlines, mask, affine=affine))
+    mask[voxel_both_true] = True
+    new = list(target_f(streamlines, mask, affine=affine))
     assert_equal(len(new), 2)
-    new = list(target(streamlines, mask, affine=affine, include=False))
+    new = list(target_f(streamlines, mask, affine=affine, include=False))
     assert_equal(len(new), 0)
 
     # only first
     mask[:] = False
-    mask[1, 0, 0] = True
-    new = list(target(streamlines, mask, affine=affine))
+    mask[voxel_one_true] = True
+    new = list(target_f(streamlines, mask, affine=affine))
     assert_equal(len(new), 1)
     assert_true(new[0] is streamlines[0])
-    new = list(target(streamlines, mask, affine=affine, include=False))
+    new = list(target_f(streamlines, mask, affine=affine, include=False))
     assert_equal(len(new), 1)
     assert_true(new[0] is streamlines[1])
 
     # Test that bad points raise a value error
-    bad_sl = [np.array([[10., 10., 10.]])]
-    new = target(bad_sl, mask, affine=affine)
-    assert_raises(ValueError, list, new)
-    bad_sl = [-np.array([[10., 10., 10.]])]
-    new = target(bad_sl, mask, affine=affine)
-    assert_raises(ValueError, list, new)
+    if test_bad_points:
+        bad_sl = streamlines + [np.array([[10.0, 10.0, 10.0]])]
+        new = target_f(bad_sl, mask, affine=affine)
+        assert_raises(ValueError, list, new)
+        bad_sl = streamlines + [-np.array([[10.0, 10.0, 10.0]])]
+        new = target_f(bad_sl, mask, affine=affine)
+        assert_raises(ValueError, list, new)
 
     # Test smaller voxels
     affine = np.random.random((4, 4)) - .5
     affine[3] = [0, 0, 0, 1]
     streamlines = list(move_streamlines(streamlines, affine))
-    new = list(target(streamlines, mask, affine=affine))
+    new = list(target_f(streamlines, mask, affine=affine))
     assert_equal(len(new), 1)
     assert_true(new[0] is streamlines[0])
-    new = list(target(streamlines, mask, affine=affine, include=False))
+    new = list(target_f(streamlines, mask, affine=affine, include=False))
     assert_equal(len(new), 1)
     assert_true(new[0] is streamlines[1])
 
-    # Test that changing mask and affine do not break target
-    include = target(streamlines, mask, affine=affine)
-    exclude = target(streamlines, mask, affine=affine, include=False)
+    # Test that changing mask or affine does not break target/target_line_based
+    include = target_f(streamlines, mask, affine=affine)
+    exclude = target_f(streamlines, mask, affine=affine, include=False)
     affine[:] = np.eye(4)
     mask[:] = False
     include = list(include)
@@ -372,7 +389,7 @@ def test_voxel_ornt():
     assert_array_equal(affine, I4)
 
     streamlines = make_streamlines()
-    box = np.array(sh)*sz
+    box = np.array(sh) * sz
 
     sra_affine = reorder_voxels_affine(ras, sra, sh, sz)
     toras_affine = reorder_voxels_affine(sra, ras, sh, sz)
@@ -427,7 +444,7 @@ def test_streamline_mapping():
     # Make the voxel size smaller
     affine = np.diag([.5, .5, .5, 1.])
     affine[:3, 3] = .25
-    expected = dict((tuple(i*2 for i in key), value)
+    expected = dict((tuple(i * 2 for i in key), value)
                     for key, value in expected.items())
     mapping = streamline_mapping(streamlines, affine=affine,
                                  mapping_as_streamlines=True)
@@ -451,8 +468,8 @@ def test_rmi():
     I1 = _rmi([A, B], dims=[1000, 1000])
     I2 = ravel_multi_index([A, B], dims=[1000, 1000])
     assert_array_equal(I1, I2)
-    I1 = _rmi([A, B, C, D], dims=[1000]*4)
-    I2 = ravel_multi_index([A, B, C, D], dims=[1000]*4)
+    I1 = _rmi([A, B, C, D], dims=[1000] * 4)
+    I2 = ravel_multi_index([A, B, C, D], dims=[1000] * 4)
     assert_array_equal(I1, I2)
     # Check for overflow with small int types
     indices = np.random.randint(0, 255, size=(2, 100))
@@ -463,7 +480,6 @@ def test_rmi():
 
 
 def test_affine_for_trackvis():
-
     voxel_size = np.array([1., 2, 3.])
     affine = affine_for_trackvis(voxel_size)
     origin = np.dot(affine, [0, 0, 0, 1])
@@ -478,7 +494,7 @@ def test_length():
 
     bundle = []
     for i in np.linspace(3, 5, n_streamlines):
-        pts = np.vstack((np.cos(2 * t/np.pi), np.zeros(t.shape) + i, t)).T
+        pts = np.vstack((np.cos(2 * t / np.pi), np.zeros(t.shape) + i, t)).T
         bundle.append(pts)
 
     start = np.random.randint(10, 30, n_streamlines)
@@ -493,7 +509,6 @@ def test_length():
 
 
 def test_seeds_from_mask():
-
     mask = np.random.random_integers(0, 1, size=(10, 10, 10))
     seeds = seeds_from_mask(mask, density=1)
     assert_equal(mask.sum(), len(seeds))
@@ -516,7 +531,6 @@ def test_seeds_from_mask():
 
 
 def test_random_seeds_from_mask():
-
     mask = np.random.random_integers(0, 1, size=(4, 6, 3))
     seeds = random_seeds_from_mask(mask,
                                    seeds_count=24,
@@ -553,9 +567,7 @@ def test_random_seeds_from_mask():
     assert_true(np.all((seeds > 1.5) & (seeds < 2.5)))
 
 
-
 def test_connectivity_matrix_shape():
-
     # Labels: z-planes have labels 0,1,2
     labels = np.zeros((3, 3, 3), dtype=int)
     labels[:, :, 1] = 1
@@ -609,3 +621,106 @@ def test_reduce_rois():
                                            [True, True])
     npt.assert_equal(include_roi, roi1 + roi2)
     npt.assert_equal(exclude_roi, np.zeros((4, 4, 4)))
+
+
+def test_flexi_tvis_affine():
+    sl_vox_order = 'RPI'
+    grid_affine = np.array(
+        [[-1.08566022e+00, 1.42664334e-03, 2.43463114e-01, 1.34783203e+02],
+         [2.43251352e-03, 1.09376717e+00, 1.48301506e-02, -1.07367630e+02],
+         [1.33170187e-01, -8.34854878e-03, 1.98454463e+00, -9.98151169e+01],
+         [0.00000000e+00, 0.00000000e+00, 0.00000000e+00, 1.00000000e+00]])
+    dim = (256, 256, 86)
+    voxel_size = np.array([1.09379995, 1.09379995, 1.99947774])
+    affine = flexi_tvis_affine(sl_vox_order, grid_affine, dim, voxel_size)
+
+    origin = np.dot(affine, [0, 0, 0, 1])
+    assert_array_almost_equal(origin[:3],
+                              np.multiply(dim, voxel_size) - voxel_size / 2)
+
+
+def test_get_flexi_tvis_affine():
+    tvis_hdr = {'voxel_order': 'RPI', 'dim': (30, 40, 50),
+                'voxel_size': [2, 3, 4]}
+
+    grid_affine = np.array([[-2, 0, 0, 0],
+                            [0, 3, 0, 0],
+                            [0, 0, 4, 0],
+                            [0, 0, 0, 1.]])
+
+    affine = get_flexi_tvis_affine(tvis_hdr, grid_affine)
+
+    origin = np.dot(affine, [0, 0, 0, 1])
+    vsz = np.array(tvis_hdr['voxel_size'])
+    assert_array_almost_equal(origin[:3],
+                              np.multiply(tvis_hdr['dim'], vsz) - vsz / 2)
+
+
+    # grid_affine =
+    tvis_hdr['voxel_order'] = 'ASL'
+    vsz = tvis_hdr['voxel_size'] = np.array([3, 4, 2.])
+    affine = get_flexi_tvis_affine(tvis_hdr, grid_affine)
+
+    vox_point = np.array([9, 8, 7])
+    trk_point = np.dot(affine, np.append(vox_point, 1))
+
+    assert_array_almost_equal(trk_point[:3],
+                              (vox_point[[1, 2, 0]] + 0.5) * vsz)
+
+
+def test_path_length():
+    aoi = np.zeros((20, 20, 20), dtype=bool)
+    aoi[0, 0, 0] = 1
+
+    # A few tests for basic usage
+    x = np.arange(20)
+    streamlines = [np.array([x, x, x]).T]
+    pl = path_length(streamlines, aoi, affine=np.eye(4))
+    expected = x.copy() * np.sqrt(3)
+    # expected[0] = np.inf
+    npt.assert_array_almost_equal(pl[x, x, x], expected)
+
+    aoi[19, 19, 19] = 1
+    pl = path_length(streamlines, aoi, affine=np.eye(4))
+    expected = np.minimum(expected, expected[::-1])
+    npt.assert_array_almost_equal(pl[x, x, x], expected)
+
+    aoi[19, 19, 19] = 0
+    aoi[1, 1, 1] = 1
+    pl = path_length(streamlines, aoi, affine=np.eye(4))
+    expected = (x - 1) * np.sqrt(3)
+    expected[0] = 0
+    npt.assert_array_almost_equal(pl[x, x, x], expected)
+
+    z = np.zeros(x.shape, x.dtype)
+    streamlines.append(np.array([x, z, z]).T)
+    pl = path_length(streamlines, aoi, affine=np.eye(4))
+    npt.assert_array_almost_equal(pl[x, x, x], expected)
+    npt.assert_array_almost_equal(pl[x, 0, 0], x)
+
+    # Only streamlines that pass through aoi contribute to path length so if
+    # all streamlines are duds, plm will be all inf.
+    aoi[:] = 0
+    aoi[0, 0, 0] = 1
+    streamlines = []
+    for i in range(1000):
+        rando = np.random.random(size=(100, 3)) * 19 + .5
+        assert (rando > .5).all()
+        assert (rando < 19.5).all()
+        streamlines.append(rando)
+    pl = path_length(streamlines, aoi, affine=np.eye(4))
+    npt.assert_array_almost_equal(pl, -1)
+
+    pl = path_length(streamlines, aoi, affine=np.eye(4), fill_value=-12.)
+    npt.assert_array_almost_equal(pl, -12.)
+
+
+def test_min_at():
+    k = np.array([3, 2, 2, 2, 1, 1, 1])
+    values = np.array([10., 1, 2, 3, 31, 21, 11])
+    i = np.zeros(k.shape, int)
+    j = np.zeros(k.shape, int)
+    a = np.zeros([1, 1, 4]) + 100.
+
+    _min_at(a, (i, j, k), values)
+    npt.assert_array_equal(a, [[[100, 11, 1, 10]]])
