@@ -1,7 +1,7 @@
 """ Testing tripwire module.
 """
 
-from ..tripwire import TripWire, is_tripwire, TripWireError
+from dipy.utils.tripwire import TripWire, is_tripwire, TripWireError
 
 from nose import SkipTest
 from nose.tools import (assert_true, assert_false, assert_raises,
@@ -20,6 +20,8 @@ def test_tripwire():
                   getattr,
                   silly_module_name,
                   'do_silly_thing')
+    assert_raises(TripWireError,
+                  silly_module_name)
     # Check AttributeError can be checked too
     try:
         silly_module_name.__wrapped__
