@@ -1,9 +1,16 @@
+# -*- coding: utf-8 -*-
 from __future__ import division, print_function, absolute_import
 
+import gzip
+from warnings import warn
+
 import numpy as np
 from scipy import ndimage
 from copy import copy
 
+from nibabel.tmpdirs import InTemporaryDirectory
+from nibabel.py3k import asbytes
+
 try:
     import Tkinter as tkinter
     has_tkinter = True
@@ -28,8 +35,8 @@ from dipy.utils.optpkg import optional_package
 from dipy import __version__ as dipy_version
 from dipy.utils.six import string_types
 
+from dipy.viz.interactor import CustomInteractorStyle
 
-# import vtk
 # Allow import, but disable doctests if we don't have vtk
 vtk, have_vtk, setup_module = optional_package('vtk')
 colors, have_vtk_colors, _ = optional_package('vtk.util.colors')
@@ -65,13 +72,18 @@ class Renderer(vtkRenderer):
         """
         self.SetBackground(color)
 
-    def add(self, actor):
+    def add(self, *actors):
         """ Add an actor to the renderer
         """
-        if isinstance(actor, vtk.vtkVolume):
-            self.AddVolume(actor)
-        else:
-            self.AddActor(actor)
+        for actor in actors:
+            if isinstance(actor, vtk.vtkVolume):
+                self.AddVolume(actor)
+            elif isinstance(actor, vtk.vtkActor2D):
+                self.AddActor2D(actor)
+            elif hasattr(actor, 'add_to_renderer'):
+                actor.add_to_renderer(self)
+            else:
+                self.AddActor(actor)
 
     def rm(self, actor):
         """ Remove a specific actor
@@ -222,6 +234,11 @@ def renderer(background=None):
     >>> fvtk.add(r,c)
     >>> #fvtk.show(r)
     """
+
+    deprecation_msg = ("Method 'dipy.viz.window.renderer' is deprecated, instead"
+                       " use class 'dipy.viz.window.Renderer'.")
+    warn(DeprecationWarning(deprecation_msg))
+
     ren = Renderer()
     if background is not None:
         ren.SetBackground(background)
@@ -308,9 +325,9 @@ class ShowManager(object):
     interactor.
     """
 
-    def __init__(self, ren, title='DIPY', size=(300, 300),
+    def __init__(self, ren=None, title='DIPY', size=(300, 300),
                  png_magnify=1, reset_camera=True, order_transparent=False,
-                 interactor_style='trackball'):
+                 interactor_style='custom'):
 
         """ Manages the visualization pipeline
 
@@ -335,8 +352,9 @@ class ShowManager(object):
             the order of their addition to the Renderer().
         interactor_style : str or vtkInteractorStyle
             If str then if 'trackball' then vtkInteractorStyleTrackballCamera()
-            is used or if 'image' then vtkInteractorStyleImage() is used (no
-            rotation). Otherwise you can input your own interactor style.
+            is used, if 'image' then vtkInteractorStyleImage() is used (no
+            rotation) or if 'custom' then CustomInteractorStyle is used.
+            Otherwise you can input your own interactor style.
 
         Attributes
         ----------
@@ -371,7 +389,8 @@ class ShowManager(object):
         >>> # showm.render()
         >>> # showm.start()
         """
-
+        if ren is None:
+            ren = Renderer()
         self.ren = ren
         self.title = title
         self.size = size
@@ -417,46 +436,22 @@ class ShowManager(object):
             self.style = vtk.vtkInteractorStyleImage()
         elif self.interactor_style == 'trackball':
             self.style = vtk.vtkInteractorStyleTrackballCamera()
+        elif self.interactor_style == 'custom':
+            self.style = CustomInteractorStyle()
         else:
             self.style = interactor_style
 
         self.iren = vtk.vtkRenderWindowInteractor()
-        self.iren.SetRenderWindow(self.window)
-
-        def key_press_standard(obj, event):
-
-            key = obj.GetKeySym()
-            if key == 's' or key == 'S':
-                print('Saving image...')
-                renderLarge = vtk.vtkRenderLargeImage()
-                if major_version <= 5:
-                    renderLarge.SetInput(ren)
-                else:
-                    renderLarge.SetInput(ren)
-                renderLarge.SetMagnification(png_magnify)
-                renderLarge.Update()
-
-                file_types = (("PNG file", "*.png"), ("All Files", "*.*"))
-                filepath = save_file_dialog(initial_file='dipy.png',
-                                            default_ext='.png',
-                                            file_types=file_types)
-                if filepath == '':
-                    print('No file was provided in the dialog')
-                else:
-                    writer = vtk.vtkPNGWriter()
-                    writer.SetInputConnection(renderLarge.GetOutputPort())
-                    writer.SetFileName(filepath)
-                    writer.Write()
-                    print('File ' + filepath + ' is saved.')
-
-        self.iren.AddObserver('KeyPressEvent', key_press_standard)
+        self.style.SetCurrentRenderer(self.ren)
+        # Hack: below, we explicitly call the Python version of SetInteractor.
+        self.style.SetInteractor(self.iren)
         self.iren.SetInteractorStyle(self.style)
+        self.iren.SetRenderWindow(self.window)
 
     def initialize(self):
         """ Initialize interaction
         """
         self.iren.Initialize()
-        # picker.Pick(85, 126, 0, ren)
 
     def render(self):
         """ Renders only once
@@ -478,14 +473,113 @@ class ShowManager(object):
             self.render()
             self.iren.Start()
 
-        # window.RemoveAllObservers()
-        # ren.SetRenderWindow(None)
-
         self.window.RemoveRenderer(self.ren)
         self.ren.SetRenderWindow(None)
         del self.iren
         del self.window
 
+    def record_events(self):
+        """ Records events during the interaction.
+
+        The recording is represented as a list of VTK events that happened
+        during the interaction. The recorded events are then returned.
+
+        Returns
+        -------
+        events : str
+            Recorded events (one per line).
+
+        Notes
+        -----
+        Since VTK only allows recording events to a file, we use a
+        temporary file from which we then read the events.
+        """
+        with InTemporaryDirectory():
+            filename = "recorded_events.log"
+            recorder = vtk.vtkInteractorEventRecorder()
+            recorder.SetInteractor(self.iren)
+            recorder.SetFileName(filename)
+
+            def _stop_recording_and_close(obj, evt):
+                recorder.Stop()
+                self.iren.TerminateApp()
+
+            self.iren.AddObserver("ExitEvent", _stop_recording_and_close)
+
+            recorder.EnabledOn()
+            recorder.Record()
+
+            self.initialize()
+            self.render()
+            self.iren.Start()
+
+            # Retrieved recorded events.
+            events = open(filename).read()
+
+        return events
+
+    def record_events_to_file(self, filename="record.log"):
+        """ Records events during the interaction.
+
+        The recording is represented as a list of VTK events
+        that happened during the interaction. The recording is
+        going to be saved into `filename`.
+
+        Parameters
+        ----------
+        filename : str
+            Name of the file that will contain the recording (.log|.log.gz).
+        """
+        events = self.record_events()
+
+        # Compress file if needed
+        if filename.endswith(".gz"):
+            gzip.open(filename, 'wb').write(asbytes(events))
+        else:
+            open(filename, 'w').write(events)
+
+    def play_events(self, events):
+        """ Plays recorded events of a past interaction.
+
+        The VTK events that happened during the recorded interaction will be
+        played back.
+
+        Parameters
+        ----------
+        events : str
+            Recorded events (one per line).
+        """
+        recorder = vtk.vtkInteractorEventRecorder()
+        recorder.SetInteractor(self.iren)
+
+        recorder.SetInputString(events)
+        recorder.ReadFromInputStringOn()
+
+        self.initialize()
+        self.render()
+        recorder.Play()
+
+    def play_events_from_file(self, filename):
+        """ Plays recorded events of a past interaction.
+
+        The VTK events that happened during the recorded interaction will be
+        played back from `filename`.
+
+        Parameters
+        ----------
+        filename : str
+            Name of the file containing the recorded events (.log|.log.gz).
+        """
+        # Uncompress file if needed.
+        if filename.endswith(".gz"):
+            with gzip.open(filename, 'r') as f:
+                events = f.read()
+        else:
+            with open(filename) as f:
+                events = f.read()
+
+        self.play_events(events)
+
     def add_window_callback(self, win_callback):
         """ Add window callbacks
         """
