@@ -78,11 +78,11 @@ fvtk.record(ren, out_path='dsid.png', size=(300, 300))
 
 """
 .. figure:: dsid.png
-    :align: center
+   :align: center
 
-    **Ground truth ODF (left), DSI ODF (middle), DSI with Deconvolution ODF(right)**
+   Ground truth ODF (left), DSI ODF (middle), DSI with Deconvolution ODF (right).
 
 .. [Canales10] Canales-Rodriguez et al., Deconvolution in Diffusion Spectrum Imaging,
-			   Neuroimage, vol 50, no 1, 136-149, 2010.
+   Neuroimage, vol 50, no 1, p. 136-149, 2010.
 
 """
