@@ -13,7 +13,7 @@ cd = os.chdir
 # Utility functions
 def c(cmd):
     """Run system command, raise SystemExit if it returns an error."""
-    print "$",cmd
+    print ("$",cmd)
     stat = os.system(cmd)
     #stat = 0  # Uncomment this and comment previous to run in debug mode
     if stat:
